@@ -1,4 +1,5 @@
 from mailerlite import MailerLiteApi
+from mailerlite.constants import API_KEY_TEST
 import requests
 
 
@@ -14,16 +15,16 @@ def test_basic_campaign():
 
     headers = {
         'content-type': "application/json",
-        'x-mailerlite-apikey': "fc7b8c5b32067bcd47cafb5f475d2fe9"
+        'x-mailerlite-apikey': API_KEY_TEST
     }
 
     response = requests.request("GET", url, headers=headers)
 
-    print(response.text)
+    # print(response.text)
 
 
 def test_create_campaign():
-    test_key = "fc7b8c5b32067bcd47cafb5f475d2fe9"
+    test_key = API_KEY_TEST
     api = MailerLiteApi(test_key)
     data = {"subject": "Regular campaign subject",
             "groups": [2984475, 3237221],
@@ -41,26 +42,27 @@ def test_create_campaign():
                }
     res = api.campaigns.create(data)
     res = api.campaigns.create(data_ab)
-    print(res)
+    # print(res)
 
 
 def test_update_campaign():
-    test_key = "fc7b8c5b32067bcd47cafb5f475d2fe9"
+    test_key = API_KEY_TEST
     api = MailerLiteApi(test_key)
 
     campaign_id = 3971635
 
-    html = '<h1>Title</h1><p>Content</p><p><small><a href=\"{$unsubscribe}\">Unsubscribe</a></small></p>'
+    html = '<h1>Title</h1><p>Content</p><p><small>'
+    html += '<a href=\"{$unsubscribe}\">Unsubscribe</a></small></p>'
     plain = "Your email client does not support HTML emails. "
     plain += "Open newsletter here: {$url}. If you do not want"
     plain += " to receive emails from us, click here: {$unsubscribe}"
     res = api.campaigns.update(campaign_id, html=html, plain=plain)
-    print(res)
+    # print(res)
 
 
 def test_campaign():
     # my_key = ""
-    test_key = "fc7b8c5b32067bcd47cafb5f475d2fe9"
+    test_key = API_KEY_TEST
     api = MailerLiteApi(test_key)
 
     _ = api.campaigns.all()
@@ -68,9 +70,3 @@ def test_campaign():
     # sub = api.subscribers
     # print(sub.search())
     # print(sub.search(search='demo@mailerlite.com'))
-
-    import ipdb; ipdb.set_trace()
-
-
-# test_basic_campaign()
-test_campaign()
